### Organizer 1.0.0
 * package:     Organizer
 * Author:     Muhammad Afaq Shuaib
 * Link:       https://github.com/AfaqShuaib09/Organizer
 

A Python package for organizing to their respective folders (i.e, images, videos, documents, etc)